@@ -5,7 +5,7 @@ produce an address space where that program is loaded and ready to run.
 The primary interface to CLE is the Loader class.
 """
 
-__version__ = "9.2.69"
+__version__ = "9.2.101"
 
 from .address_translator import AT, AddressTranslator
 from .backends import (
@@ -35,6 +35,7 @@ from .backends import (
     Section,
     Segment,
     Soot,
+    SRec,
     StaticArchive,
     Symbol,
     SymbolSubType,
@@ -88,6 +89,7 @@ __all__ = [
     "FunctionHint",
     "FunctionHintSource",
     "Hex",
+    "SRec",
     "Jar",
     "MachO",
     "MetaELF",
