@@ -1,6 +1,7 @@
 from .backend import ALL_BACKENDS, Backend, ExceptionHandling, FunctionHint, FunctionHintSource, register_backend
 from .blob import Blob
 from .cgc import CGC, BackedCGC
+from .coff import Coff
 from .elf import ELF, ELFCore, MetaELF
 from .ihex import Hex
 from .java.apk import Apk
@@ -12,6 +13,7 @@ from .named_region import NamedRegion
 from .pe import PE
 from .region import Region, Section, Segment
 from .regions import Regions
+from .srec import SRec
 from .static_archive import StaticArchive
 from .symbol import Symbol, SymbolSubType, SymbolType
 from .te import TE
@@ -32,10 +34,12 @@ __all__ = [
     "ELFCore",
     "MetaELF",
     "PE",
+    "Coff",
     "Blob",
     "CGC",
     "BackedCGC",
     "Hex",
+    "SRec",
     "Minidump",
     "MachO",
     "NamedRegion",
