@@ -2,6 +2,7 @@
 import copy
 import logging
 import os
+import pathlib
 import xml.etree.ElementTree
 from collections import OrderedDict, defaultdict
 from typing import Dict, List, Optional, Set, Tuple
@@ -108,7 +109,7 @@ class ELF(MetaELF):
                 raise CLECompatibilityError from e1
 
         # Get an appropriate archinfo.Arch for this binary, unless the user specified one
-        if self.arch is None:
+        if self._arch is None:
             self.set_arch(self.extract_arch(self._reader))
         else:
             try:
@@ -382,7 +383,7 @@ class ELF(MetaELF):
         :param symid: Either an index into .dynsym or the name of a symbol.
         """
         version = None
-        if type(symid) is int:
+        if isinstance(symid, int):
             if symid == 0:
                 # special case the null symbol, this is important for static binaries
                 return self._nullsymbol
@@ -399,7 +400,7 @@ class ELF(MetaELF):
                 return cached
             if self.hashtable is not None and symbol_table is self.hashtable.symtab and self._vertable is not None:
                 version = self._vertable.get_symbol(symid).entry.ndx
-        elif type(symid) is str:
+        elif isinstance(symid, str):
             if not symid:
                 log.warning("Trying to resolve a symbol by its empty name")
                 return None
@@ -550,7 +551,7 @@ class ELF(MetaELF):
 
         self.memory.add_backer(AT.from_lva(mapstart, self).to_rva(), data, overwrite=True)
 
-    def _make_reloc(self, readelf_reloc, symbol, dest_section=None):
+    def _make_reloc(self, readelf_reloc, symbol, dest_section: Optional[ELFSection] = None):
         addend = readelf_reloc.entry.r_addend if readelf_reloc.is_RELA() else None
         RelocClass = get_relocation(self.arch.name, readelf_reloc.entry.r_info_type)
         if RelocClass is None:
@@ -558,7 +559,10 @@ class ELF(MetaELF):
 
         address = AT.from_lva(readelf_reloc.entry.r_offset, self).to_rva()
         if dest_section is not None:
-            address += dest_section.remap_offset
+            # note to the intrepid explorer: this code was changed as per cle#467
+            # address += dest_section.remap_offset
+            if self.is_relocatable:
+                address += AT.from_mva(dest_section.vaddr, self).to_rva()
 
         try:
             return RelocClass(self, symbol, address, addend)
@@ -577,7 +581,7 @@ class ELF(MetaELF):
 
         try:
             for entry in dwarf.EH_CFI_entries():
-                if type(entry) is callframe.FDE:
+                if isinstance(entry, callframe.FDE):
                     self.function_hints.append(
                         FunctionHint(
                             entry.header["initial_location"],
@@ -600,7 +604,11 @@ class ELF(MetaELF):
         try:
             lsda = LSDAExceptionTable(self._binary_stream, self.arch.bits, self.arch.memory_endness == "Iend_LE")
             for entry in dwarf.EH_CFI_entries():
-                if type(entry) is callframe.FDE and hasattr(entry, "lsda_pointer") and entry.lsda_pointer is not None:
+                if (
+                    isinstance(entry, callframe.FDE)
+                    and hasattr(entry, "lsda_pointer")
+                    and entry.lsda_pointer is not None
+                ):
                     # function address
                     func_addr = entry.header.get("initial_location", None)
                     if func_addr is None:
@@ -654,19 +662,19 @@ class ELF(MetaELF):
                 else:
                     file_entry = lineprog.header["file_entry"][line.state.file - 1]
                     if file_entry["dir_index"] == 0:
-                        filename = os.path.join(comp_dir, file_entry.name.decode())
+                        filename = pathlib.PurePosixPath(comp_dir) / file_entry.name.decode()
                     else:
-                        filename = os.path.join(
-                            comp_dir,
-                            lineprog.header["include_directory"][file_entry["dir_index"] - 1].decode(),
-                            file_entry.name.decode(),
+                        filename = (
+                            pathlib.PurePosixPath(comp_dir)
+                            / lineprog.header["include_directory"][file_entry["dir_index"] - 1].decode()
+                            / file_entry.name.decode()
                         )
                     file_cache[line.state.file] = filename
 
                 relocated_addr = AT.from_lva(line.state.address, self).to_mva()
                 if relocated_addr not in self.addr_to_line:
                     self.addr_to_line[relocated_addr] = set()
-                self.addr_to_line[relocated_addr].add((filename, line.state.line))
+                self.addr_to_line[relocated_addr].add((str(filename), line.state.line))
 
     @staticmethod
     def _load_low_high_pc_form_die(die: DIE):
@@ -1045,9 +1053,6 @@ class ELF(MetaELF):
         return parts
 
     def __register_relocs(self, section, dynsym=None, force_jmprel=False):
-        if not self.loader._perform_relocations:
-            return
-
         got_min = got_max = 0
 
         if not force_jmprel:
